# mirzai
> Reproducible research code for: "Prediction of Exchangeable Potassium in Soil through Mid-Infrared Spectroscopy and Deep Learning: from Prediction to Explainability", Albinet et al., 2022


## Install

`pip install mirzai`

## How to use

Link to tutorials nbs...
